"""
MCPStore Context Module
提供 MCPStore 的上下文管理功能

此模块已重构为多个子模块以提高可维护性：
- base_context: 核心上下文类和基础功能
- service_operations: 服务相关操作
- tool_operations: 工具相关操作
- resources_prompts: Resources和Prompts功能
- advanced_features: 高级功能
"""

# 导入所有公共接口以保持向后兼容
from .context.types import ContextType
from .context.base_context import MCPStoreContext

# 保持向后兼容的导出
__all__ = ["ContextType", "MCPStoreContext"]
